@@ -13,16 +13,11 @@ from config import settings
 # Apps
 APPS = settings.apps
 
-# print(settings.keys)
-# print(settings.mode)
-# http://localhost:8000/graphql
-
 # FastAPI
 app = FastAPI(
     description=settings.docs,
     title=settings.base.app_name,
     version=settings.base.version,
-    terms_of_service="http://example.com/terms/",
 )
 
 # Middleware
